@@ -61,6 +61,9 @@ class BiCoN(object):
         show_plot - set true if convergence plots should be shown
         save - set an output file name  if the convergence plot should be saved in the end
         show_nets - set true if the selected network should be shown at each iteration
+        verbose - set true to print information about the algorithm's progress
+        logging - set true to save information about algorithm's progress to bicon_logging.txt file
+
 
         """
         assert n_proc > 0, "Set a correct number for n_proc, right now the value is {0}".format(n_proc)
@@ -264,7 +267,7 @@ class BiCoN(object):
             #                       'the signal in the data is too weak. Try selecting more genes (e.g. 3000)'
             if count_big == 0 and verbose:
                 print("One full iteration takes {0} with {1} processes".format(round(time.time() - st, 2), n_proc))
-            if count_big == 0 and verbose:
+            if count_big == 0 and logging:
                 f.write("One full iteration takes {0} with {1} processes".format(round(time.time() - st, 2), n_proc))
                 f.write("\n")
 
